==> infinitubes-55.0.6.jar: src/mods/immibis/infinitubes/DislocatorTile.java <==
package mods.immibis.infinitubes;


import java.util.concurrent.atomic.AtomicInteger;

import mods.immibis.core.MainThreadTaskQueue;
import mods.immibis.core.api.MultiInterfaceClass;
import mods.immibis.core.api.MultiInterfaceClass.Interface;

import cpw.mods.fml.relauncher.Side;
import dan200.computer.api.IComputerAccess;
import dan200.computer.api.IPeripheral;

@MultiInterfaceClass(
	base="mods.immibis.infinitubes.DislocatorTileBase",
	interfaces={
		@Interface(check="dan200.computer.api.IPeripheral", impl="mods.immibis.infinitubes.DislocatorTile$CCImpl")
	})
public class DislocatorTile extends DislocatorTileBase {
	public static class CCImpl extends DislocatorTileBase implements IPeripheral {

		@Override
		public void attach(IComputerAccess arg0) {
		}
		
		private static AtomicInteger nextID = new AtomicInteger(0);

		@Override
		public Object[] callMethod(final IComputerAccess computer, int methodNum, Object[] args) throws Exception {
			
			int amt;
			String search, eject;
			
			try {
				amt = (int)(double)(Double)args[0];
				search = (String)args[1];
				eject = (String)args[2];
			} catch(Exception e) {
				throw new Exception("Usage: dislocator.pull(int stackSize, string searchLabel, string ejectLabel)");
			}
			
			if(amt < 1 || amt > 64)
				throw new Exception("stack size must be from 1 to 64");
			
			final int amt2 = amt;
			final String search2 = search, eject2 = eject;
			
			final int requestID = nextID.getAndIncrement();
			
			MainThreadTaskQueue.enqueue(new Runnable() {
				
				@Override
				public void run() {
					CCImpl te = CCImpl.this;
					
					String oldF = te.filter, oldL = te.label;
					String[] oldCF = te.cachedFilter;
					
					te.filter = search2;
					te.label = eject2;
					te.cachedFilter = null;
					
					boolean result = te.suck(amt2);
					
					te.cachedFilter = oldCF;
					te.filter = oldF;
					te.label = oldL;
					
					computer.queueEvent("dislocator_done", new Object[] {requestID, result});
				}
				
			}, Side.SERVER);
			
			return new Object[] {requestID};
		}

		@Override
		public boolean canAttachToSide(int arg0) {
			return true;
		}

		@Override
		public void detach(IComputerAccess arg0) {
		}

		@Override
		public String[] getMethodNames() {
			return new String[] {
				"pull"
			};
		}

		@Override
		public String getType() {
			return "dislocator";
		}
		
	}
}

==> infinitubes-56.0.0.jar: src/mods/immibis/infinitubes/DislocatorTile.java <==
package mods.immibis.infinitubes;


import java.util.concurrent.atomic.AtomicInteger;

import mods.immibis.core.MainThreadTaskQueue;
import mods.immibis.core.api.MultiInterfaceClass;
import mods.immibis.core.api.MultiInterfaceClass.Interface;

import cpw.mods.fml.relauncher.Side;
import dan200.computer.api.IComputerAccess;
import dan200.computer.api.ILuaContext;
import dan200.computer.api.IPeripheral;

@MultiInterfaceClass(
	base="mods.immibis.infinitubes.DislocatorTileBase",
	interfaces={
		@Interface(check="dan200.computer.api.IPeripheral", impl="mods.immibis.infinitubes.DislocatorTile$CCImpl")
	})
public class DislocatorTile extends DislocatorTileBase {
	public static class CCImpl extends DislocatorTileBase implements IPeripheral {

		@Override
		public void attach(IComputerAccess arg0) {
		}
		
		private static AtomicInteger nextID = new AtomicInteger(0);

		@Override
		public Object[] callMethod(final IComputerAccess computer, ILuaContext ctx, int methodNum, Object[] args) throws Exception {
			
			int amt;
			String search, eject;
			
			try {
				amt = (int)(double)(Double)args[0];
				search = (String)args[1];
				eject = (String)args[2];
			} catch(Exception e) {
				throw new Exception("Usage: dislocator.pull(int stackSize, string searchLabel, string ejectLabel)");
			}
			
			if(amt < 1 || amt > 64)
				throw new Exception("stack size must be from 1 to 64");
			
			final int amt2 = amt;
			final String search2 = search, eject2 = eject;
			
			final int requestID = nextID.getAndIncrement();
			
			MainThreadTaskQueue.enqueue(new Runnable() {
				
				@Override
				public void run() {
					CCImpl te = CCImpl.this;
					
					String oldF = te.filter, oldL = te.label;
					String[] oldCF = te.cachedFilter;
					
					te.filter = search2;
					te.label = eject2;
					te.cachedFilter = null;
					
					boolean result = te.suck(amt2);
					
					te.cachedFilter = oldCF;
					te.filter = oldF;
					te.label = oldL;
					
					computer.queueEvent("dislocator_done", new Object[] {requestID, result});
				}
				
			}, Side.SERVER);
			
			return new Object[] {requestID};
		}

		@Override
		public boolean canAttachToSide(int arg0) {
			return true;
		}

		@Override
		public void detach(IComputerAccess arg0) {
		}

		@Override
		public String[] getMethodNames() {
			return new String[] {
				"pull"
			};
		}

		@Override
		public String getType() {
			return "dislocator";
		}
		
	}
}
